import React from "react";
import PropTypes from "prop-types";
import { TableCell, TableRow, IconButton } from "@material-ui/core";
import Collapse from "@material-ui/core/Collapse";
import KeyboardArrowDownIcon from "@material-ui/icons/KeyboardArrowDown";
import KeyboardArrowUpIcon from "@material-ui/icons/KeyboardArrowUp";
import { makeStyles } from "@material-ui/core/styles";
import MachineLog from "./MachineLog";

const useRowStyles = makeStyles({
  root: {
    "& > *": {
      borderBottom: "unset"
    }
  }
});

const MachineItem = ({ machine }) => {
  const [open, setOpen] = React.useState(false);
  const classes = useRowStyles();

  return (
    <React.Fragment>
      <TableRow className={classes.root}>
        <TableCell>
          <IconButton
            aria-label="expand row"
            size="small"
            onClick={() => setOpen(!open)}
          >
            {open ? <KeyboardArrowUpIcon /> : <KeyboardArrowDownIcon />}
          </IconButton>
        </TableCell>
        <TableCell component="th" scope="row">
          {machine.fullMachineName}
        </TableCell>
        <TableCell>{machine.machineName}</TableCell>
        <TableCell>{machine.iPv4Address}</TableCell>
        <TableCell align="right">{"buttons"}</TableCell>
      </TableRow>
      <TableRow>
        <TableCell style={{ paddingBottom: 0, paddingTop: 0 }} colSpan={6}>
          <Collapse in={open} timeout="auto" unmountOnExit>
            <MachineLog />
          </Collapse>
        </TableCell>
      </TableRow>
    </React.Fragment>
  );
};

MachineItem.propTypes = {
  machine: PropTypes.shape({
    machineId: PropTypes.number.isRequired,
    machineName: PropTypes.string.isRequired,
    fullMachineName: PropTypes.string.isRequired,
    macAddress: PropTypes.string.isRequired,
    iPv4Address: PropTypes.string,
    description: PropTypes.string
  }).isRequired
};

export default MachineItem;
