import React, { useContext, useEffect, useCallback } from "react";
import {
  ApplicationStateContext,
  ApplicationDispatchContext
} from "../../../state/ApplicationContexts";
import { readMachines } from "../api";
import NetworkComponent from "./NetworkComponent";

const NetworkContainer = () => {
  const state = useContext(ApplicationStateContext);
  const dispatchActions = useContext(ApplicationDispatchContext);

  const handleChange = prop => event => {
    dispatchActions.onNetworkChange(prop, event.target.value);
  };

  const handleReadMachines = useCallback(async () => {
    const machines = await readMachines();
    const data = Object.assign(machines, { loaded: true });
    dispatchActions.onNetworkChange("machines", data);
  }, [dispatchActions]);

  useEffect(() => {
    if (!state.network.machines.loaded) {
      handleReadMachines();
    }
  }, [handleReadMachines, state.network.machines.loaded]);

  return (
    <NetworkComponent network={state.network} onPropertyChange={handleChange} />
  );
};

export default NetworkContainer;
